=begin
------------------------------------------------------------------------
Copyright 2009, TIG (c)
Permission to use, copy, modify, and distribute this software for any 
purpose, and currently without fee, is hereby granted, provided that  
this text and the above copyright (c) notice appear in all copies.
This software is provided "as is" and without any express or implied 
warranties, including, without limitation, the implied warranties of 
merchantability and fitness for a particular purpose.
------------------------------------------------------------------------
Name:          	SelectAllFacesByMaterial.rb
Description:   	Selects Faces* by Material Globally in Selection - 
				        including mining into Groups/Definitions.
Author:       	TIG
Usage:	1. Select faces / entities.
				[IF NO selection ALL active entities are used] 
				2. Activate the script from the Plugins Menu.
				3. Choose Material.
        << DEFAULT >> = ALL Faces that have NO Materials
				and then an Alphabetical list of other Materials in the Model.			
				4. Choose the desired Material.
				To access Materials that are off the visible list type 
				the first letter - e.g. 'W' and use up/down arrow-keys 
				to move to the one you want e.g. 'W'hite...
        5. All Faces* are selected.
        *Note: to also include groups and instances etc put # in front of 
        'and e.typename=="Face"' on line #59...
History: 1.0 20090423	First issue.
=end
#-----------------------------------------------------------------------------
require 'sketchup.rb' 
class SelectAllFacesByMaterial 
 def select()  
  # get the materials
	model=Sketchup.active_model
  selection=model.selection
  (model.active_entities.each{|e|Sketchup.active_model.selection.add(e)})if selection.empty?
	mats=model.materials
	matNames=["<< DEFAULT >>"]
	matNstmp=[]
	mats.each{|m|matNstmp.push(m.display_name)}
	matNstmp.sort!
	matNames=matNames+matNstmp
	matList=matNames.join('|')
	# dialogs
	info=[matList]
    prompts=["Face Material to be Selected: "]
    values=["<< DEFAULT >>"]
    results=inputbox(prompts,values,info,"Face Material to be Selected")
  return nil if ! results
	material=results[0]
  material=nil if material=="<< DEFAULT >>"
  selection=selection.to_a
  Sketchup.active_model.selection.clear
  def material_miner(ents,mat)
   ents.each{|e|
     material_miner(e.entities.to_a,mat)if e.typename=="Group"
     material_miner(e.definition.entities.to_a,mat)if e.typename=="ComponentInstance"
     Sketchup.active_model.selection.add(e)if(e.material and e.material.display_name==mat) and e.typename=="Face"
   }
  end#def
  material_miner(selection,material)
 end#def
end#class
#-----------------------------------------------------------------------
def selectallfacesbymaterial
  model=Sketchup.active_model
  model.start_operation("Select All Faces by Material")
    #if ! model.selection[0]
      #return nil if UI.messagebox("This will affect ALL Faces !\nContinue ?",MB_YESNO,"ALL ?")==7### 6=YES 7=NO
    #end#if
    SelectAllFacesByMaterial.new.select
  model.commit_operation
end#def
#-----------------------------------------------------------------------
is_this_file=File.basename(__FILE__)
if not file_loaded?(is_this_file)
  UI.menu("Plugins").add_item("Select All Faces by Material"){selectallfacesbymaterial}
end#if
#-----------------------------------------------------------------------
file_loaded(is_this_file)
